==> eslint-config-aftership-4.2.1.tgz: package/rules/errors.js <==
'use strict';

module.exports = {
	rules: {
		// for server side, this feature is way too early to have
		'comma-dangle': ['error', {
			arrays: 'never',
			objects: 'never',
			imports: 'never',
			exports: 'never',
			functions: 'never'
		}],

		// Disallow await inside of loops
		// sometimes we have to based on previous result to perform retry logics
		// http://eslint.org/docs/rules/no-await-in-loop
		'no-await-in-loop': 'off',

		// Disallow comparisons to negative zero
		// http://eslint.org/docs/rules/no-compare-neg-zero
		'no-compare-neg-zero': 'error',

		// disallow assignment in conditional expressions
		// http://eslint.org/docs/rules/no-cond-assign
		'no-cond-assign': ['error', 'always'],

		// disallow use of console
		// at the time being it's not possible for our projects
		// http://eslint.org/docs/rules/no-console
		'no-console': 'off',

		// disallow use of constant expressions in conditions
		'no-constant-condition': 'warn',

		// disallow control characters in regular expressions
		'no-control-regex': 'error',

		// disallow use of debugger
		'no-debugger': 'error',

		// disallow duplicate arguments in functions
		'no-dupe-args': 'error',

		// disallow duplicate keys when creating object literals
		'no-dupe-keys': 'error',

		// disallow a duplicate case label.
		'no-duplicate-case': 'error',

		// disallow empty statements
		'no-empty': 'error',

		// disallow the use of empty character classes in regular expressions
		'no-empty-character-class': 'error',

		// disallow assigning to the exception in a catch block
		'no-ex-assign': 'error',

		// disallow double-negation boolean casts in a boolean context
		// http://eslint.org/docs/rules/no-extra-boolean-cast
		'no-extra-boolean-cast': 'error',

		// disallow unnecessary parentheses
		// http://eslint.org/docs/rules/no-extra-parens
		'no-extra-parens': ['off', 'all', {
			conditionalAssign: true,
			nestedBinaryExpressions: false,
			returnAssign: false
		}],

		// disallow unnecessary semicolons
		'no-extra-semi': 'error',

		// disallow overwriting functions written as function declarations
		'no-func-assign': 'error',

		// disallow function or variable declarations in nested blocks
		'no-inner-declarations': 'error',

		// disallow invalid regular expression strings in the RegExp constructor
		'no-invalid-regexp': 'error',

		// disallow irregular whitespace outside of strings and comments
		'no-irregular-whitespace': 'error',

		// disallow the use of object properties of the global object (Math and JSON) as functions
		'no-obj-calls': 'error',

		// disallow use of Object.prototypes builtins directly
		// http://eslint.org/docs/rules/no-prototype-builtins
		'no-prototype-builtins': 'error',

		// disallow multiple spaces in a regular expression literal
		'no-regex-spaces': 'error',

		// disallow sparse arrays
		'no-sparse-arrays': 'error',

		// Disallow template literal placeholder syntax in regular strings
		// http://eslint.org/docs/rules/no-template-curly-in-string
		'no-template-curly-in-string': 'error',

		// Avoid code that looks like two expressions but is actually one
		// http://eslint.org/docs/rules/no-unexpected-multiline
		'no-unexpected-multiline': 'error',

		// disallow unreachable statements after a return, throw, continue, or break statement
		'no-unreachable': 'error',

		// disallow return/throw/break/continue inside finally blocks
		// http://eslint.org/docs/rules/no-unsafe-finally
		'no-unsafe-finally': 'error',

		// disallow negating the left operand of relational operators
		// http://eslint.org/docs/rules/no-unsafe-negation
		'no-unsafe-negation': 'error',
		// disallow negation of the left operand of an in expression
		// deprecated in favor of no-unsafe-negation
		'no-negated-in-lhs': 'off',

		// disallow comparisons with the value NaN
		'use-isnan': 'error',

		// ensure JSDoc comments are valid
		// http://eslint.org/docs/rules/valid-jsdoc
		'valid-jsdoc': 'off',

		// ensure that the results of typeof are compared against a valid string
		// http://eslint.org/docs/rules/valid-typeof
		'valid-typeof': ['error', {requireStringLiterals: true}]
	}
};

==> eslint-config-aftership-4.3.0.tgz: package/rules/errors.js <==
'use strict';

module.exports = {
	rules: {
		// for server side, this feature is way too early to have
		'comma-dangle': ['error', {
			arrays: 'never',
			objects: 'never',
			imports: 'never',
			exports: 'never',
			functions: 'never'
		}],

		// Disallow await inside of loops
		// sometimes we have to based on previous result to perform retry logics
		// http://eslint.org/docs/rules/no-await-in-loop
		'no-await-in-loop': 'off',

		// Disallow comparisons to negative zero
		// http://eslint.org/docs/rules/no-compare-neg-zero
		'no-compare-neg-zero': 'error',

		// disallow assignment in conditional expressions
		// http://eslint.org/docs/rules/no-cond-assign
		'no-cond-assign': ['error', 'always'],

		// disallow use of console
		// http://eslint.org/docs/rules/no-console
		// we force ppl to use better practice to log things, e.g. bunyan/winston
		'no-console': 'error',

		// disallow use of constant expressions in conditions
		'no-constant-condition': 'warn',

		// disallow control characters in regular expressions
		'no-control-regex': 'error',

		// disallow use of debugger
		'no-debugger': 'error',

		// disallow duplicate arguments in functions
		'no-dupe-args': 'error',

		// disallow duplicate keys when creating object literals
		'no-dupe-keys': 'error',

		// disallow a duplicate case label.
		'no-duplicate-case': 'error',

		// disallow empty statements
		'no-empty': 'error',

		// disallow the use of empty character classes in regular expressions
		'no-empty-character-class': 'error',

		// disallow assigning to the exception in a catch block
		'no-ex-assign': 'error',

		// disallow double-negation boolean casts in a boolean context
		// http://eslint.org/docs/rules/no-extra-boolean-cast
		'no-extra-boolean-cast': 'error',

		// disallow unnecessary parentheses
		// http://eslint.org/docs/rules/no-extra-parens
		'no-extra-parens': ['off', 'all', {
			conditionalAssign: true,
			nestedBinaryExpressions: false,
			returnAssign: false
		}],

		// disallow unnecessary semicolons
		'no-extra-semi': 'error',

		// disallow overwriting functions written as function declarations
		'no-func-assign': 'error',

		// disallow function or variable declarations in nested blocks
		'no-inner-declarations': 'error',

		// disallow invalid regular expression strings in the RegExp constructor
		'no-invalid-regexp': 'error',

		// disallow irregular whitespace outside of strings and comments
		'no-irregular-whitespace': 'error',

		// disallow the use of object properties of the global object (Math and JSON) as functions
		'no-obj-calls': 'error',

		// disallow use of Object.prototypes builtins directly
		// http://eslint.org/docs/rules/no-prototype-builtins
		'no-prototype-builtins': 'error',

		// disallow multiple spaces in a regular expression literal
		'no-regex-spaces': 'error',

		// disallow sparse arrays
		'no-sparse-arrays': 'error',

		// Disallow template literal placeholder syntax in regular strings
		// http://eslint.org/docs/rules/no-template-curly-in-string
		'no-template-curly-in-string': 'error',

		// Avoid code that looks like two expressions but is actually one
		// http://eslint.org/docs/rules/no-unexpected-multiline
		'no-unexpected-multiline': 'error',

		// disallow unreachable statements after a return, throw, continue, or break statement
		'no-unreachable': 'error',

		// disallow return/throw/break/continue inside finally blocks
		// http://eslint.org/docs/rules/no-unsafe-finally
		'no-unsafe-finally': 'error',

		// disallow negating the left operand of relational operators
		// http://eslint.org/docs/rules/no-unsafe-negation
		'no-unsafe-negation': 'error',
		// disallow negation of the left operand of an in expression
		// deprecated in favor of no-unsafe-negation
		'no-negated-in-lhs': 'off',

		// disallow comparisons with the value NaN
		'use-isnan': 'error',

		// ensure JSDoc comments are valid
		// http://eslint.org/docs/rules/valid-jsdoc
		'valid-jsdoc': 'off',

		// ensure that the results of typeof are compared against a valid string
		// http://eslint.org/docs/rules/valid-typeof
		'valid-typeof': ['error', {requireStringLiterals: true}]
	}
};
